<?php
namespace Ep\Wp\Middleware;

use Ep\Middleware\BaseUrl;
use Interop\Http\Server\MiddlewareInterface;
use Interop\Http\Server\RequestHandlerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

/**
 * Deklarira WordPress konstante
 *
 * @package Ep\Wp\Middleware
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-wordpress
 */
class Constants implements MiddlewareInterface
{
    /** @var array */
    private $config;

    /**
     * Constants constructor.
     *
     * @param array $config
     */
    public function __construct(array $config)
    {
        $this->config = $config['wp'] ?? [];
    }

    /**
     * Deklrarira konstante.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler)
    {
        define('AUTH_KEY', $this->config['auth_key'] ?? '');
        define('SECURE_AUTH_KEY', $this->config['secure_auth_key'] ?? '');
        define('LOGGED_IN_KEY', $this->config['logged_in_key'] ?? '');
        define('NONCE_KEY', $this->config['nonce_key'] ?? '');
        define('AUTH_SALT', $this->config['auth_salt'] ?? '');
        define('SECURE_AUTH_SALT', $this->config['secure_auth_salt'] ?? '');
        define('LOGGED_IN_SALT', $this->config['logged_in_salt'] ?? '');
        define('NONCE_SALT', $this->config['nonce_salt'] ?? '');

        define('WP_DEBUG', $this->config['debug'] ?? false);

        $baseUrl = $request->getAttribute(BaseUrl::BASE_URL, '/');
        $baseUrl = preg_replace('#/wp(/wp-admin)?/?#', '', $baseUrl);

        $home = $request->getUri()
                        ->withPath($baseUrl)
                        ->withQuery('');

        define('WP_HOME', rtrim($home, '/'));
        define('WP_SITEURL', WP_HOME . '/wp');

        define('WP_CONTENT_DIR', dirname(ABSPATH) . '/wp-content');
        define('WP_CONTENT_URL', WP_HOME . '/wp-content');

        return $handler->handle($request);
    }
}