<?php
namespace Ep\Wp\Middleware;

use Interop\Http\Server\MiddlewareInterface;
use Interop\Http\Server\RequestHandlerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Zend\Db\Adapter\AdapterInterface;
use Zend\Db\Adapter\Driver\Pdo\Pdo;

/**
 * Daje WordPressu bazu iz containera.
 *
 * @package Ep\WordPress\Middleware
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-wordpress
 */
class Database implements MiddlewareInterface
{
    /** @var AdapterInterface */
    private $db;

    /**
     * Database constructor.
     *
     * @param AdapterInterface $db
     */
    public function __construct(AdapterInterface $db)
    {
        $this->db = $db;
    }

    /**
     * Deklarira konstante s podacima za bazu koje WordPress očekuje.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler)
    {
        /** @var Pdo $driver */
        $driver = $this->db->getDriver();
        $params = $driver->getConnection()->getConnectionParameters();

        define('DB_NAME', $params['database'] ?? '');
        define('DB_USER', $params['username'] ?? '');
        define('DB_PASSWORD', $params['password'] ?? '');
        define('DB_HOST', $params['hostname'] ?? '');
        define('DB_CHARSET', 'utf8mb4');
        define('DB_COLLATE', 'utf8mb4_general_ci');

        return $handler->handle($request);
    }
}