<?php
namespace Ep\Wp\Middleware;

use Ep\Wp\Plugin\PluginManager;
use Interop\Http\Server\MiddlewareInterface;
use Interop\Http\Server\RequestHandlerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

/**
 * Omogućava korištenje custom pluginova.
 *
 * @package Ep\Wp\Middleware
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-wordpress
 */
class Plugins implements MiddlewareInterface
{
    /** @var PluginManager */
    private $plugins;
    /** @var array */
    private $config;

    /**
     * Plugins constructor.
     *
     * @param PluginManager $plugins
     */
    public function __construct(PluginManager $plugins, array $config)
    {
        $this->plugins = $plugins;
        $this->config = $config['wp'] ?? [];
    }

    /**
     * Inicijalizira neke naše pluginove.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler)
    {
        require_once ABSPATH . 'wp-includes/plugin.php';

        foreach ($this->config['plugins'] ?? [] as $name) {
            $plugin = $this->plugins->get($name);
            $plugin();
        }

        return $handler->handle($request);
    }
}